How to:
=======

This section of the documentation is aimed at those who want to know how to
carry out a specific task with :code:`nbchkr`.

How to:

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install.rst
   write_an_assignment.rst
   release_a_source_assignment.rst
   solve_an_assignment.rst
   check_a_submission.rst
   handle_a_submission_in_the_wrong_format.rst
   contribute.rst
   release.rst
